@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 1;
 __END__
@@ -12,7 +12,7 @@ __END__
 
 =head1 NAME
 
-App::cpanoutdated::coro - faster C<cpan-outdated> using a little more resources
+App::cpanoutdated::coro - faster C<cpan-outdated>
 
 =head1 DESCRIPTION
 
